@@ -1,3 +1,5 @@
+import logging
+
 from bson.json_util import CANONICAL_JSON_OPTIONS, dumps, loads
 
 POWERBUS_PATH = "/run/funtoo/powerbus-socket"
@@ -15,7 +17,9 @@ class PowerBusMessage(dict):
 
 	async def send(self, socket):
 		"""Send message to websocket"""
-		await socket.send_str(self.msg)
+		msg = self.msg
+		logging.debug(f"Sending message {msg}")
+		await socket.send_str(msg)
 
 	def __getattr__(self, key):
 		if key not in self:
