@@ -170,7 +170,6 @@ async def setup_lid_callback():
 		my_dict = dict(my_dict)
 		if "LidIsClosed" in my_dict:
 			if my_dict["LidIsClosed"].value:
-				print(str(my_dict["LidIsClosed"]))
 				logging.warning("Lid is closed!")
 				LID_LAST_CLOSED = get_utc_time()
 				LID_CLOSED_EVENT.set()
@@ -285,7 +284,7 @@ class PowerBusDaemon(object):
 		for client_key, datums in self.clients.items():
 			ws, orig_msg_obj = datums
 			if cur_time - orig_msg_obj.time <= self.client_stale_timeout:
-				print("Sending message", msg_obj)
+				logging.warning("Sending message", msg_obj)
 				await msg_obj.send(ws)
 
 	async def tell_clients_to_prepare_for_sleep(self):
@@ -633,10 +632,10 @@ class PowerBusDaemon(object):
 		sys.stdout.flush()
 
 		if msg_time > cur_time:
-			print("message from FUTURE!")
+			logging.warning("message from FUTURE!")
 			return
 		elif cur_time - msg_time > self.stale_msg_interval:
-			print("OLD message!")
+			logging.warning("OLD message!")
 			return
 
 		client_key = set()
